Statistics
==========

.. currentmodule:: numpy


Extremal values
---------------

.. autosummary::
   :toctree: generated/

   amin
   amax
   nanmax
   nanmin
   ptp

Averages and variances
----------------------

.. autosummary::
   :toctree: generated/

   average
   mean
   median
   std
   var

Correlating
-----------

.. autosummary::
   :toctree: generated/

   corrcoef
   correlate
   cov

Histograms
----------

.. autosummary::
   :toctree: generated/

   histogram
   histogram2d
   histogramdd
   bincount
   digitize
